pilas.fisica.Fisica

Package pilas :: Module fisica :: Class Fisica |
[hide private]
[frames] | no frames]

# Class Fisica

source code

    object --+
             |
            Fisica

Representa un simulador de mundo fisico, usando la biblioteca Box2D (version 2.1).

Instance Methods | [hide private]
__init__(self, area, gravedad) Inicializa el motor de física. | source code
crear_bordes_del_escenario(self) Genera las paredes, el techo y el suelo. | source code
reiniciar(self) Elimina todos los objetos físicos y vuelve a crear el entorno. | source code
capturar_figura_con_el_mouse(self, figura) Comienza a capturar una figura con el mouse. | source code
cuando_mueve_el_mouse(self, x, y) Gestiona el evento de movimiento del mouse. | source code
cuando_suelta_el_mouse(self) Se ejecuta cuando se suelta el botón de mouse. | source code
actualizar(self, velocidad=1.0) Realiza la actualización lógica del escenario. | source code
pausar_mundo(self) Detiene la simulación física. | source code
reanudar_mundo(self) Restaura la simulación física. | source code
_procesar_figuras_a_eliminar(self) Elimina las figuras que han sido marcadas para quitar. | source code
dibujar_figuras_sobre_lienzo(self, motor, lienzo, grosor=1) Dibuja todas las figuras en una pizarra. | source code
crear_cuerpo(self, definicion_de_cuerpo) Genera un Body de box2d. | source code
crear_suelo(self, (ancho, alto), restitucion=0) Genera un suelo sólido para el escenario. | source code
crear_techo(self, (ancho, alto), restitucion=0) Genera un techo sólido para el escenario. | source code
crear_paredes(self, (ancho, alto), restitucion=0) Genera dos paredes para el escenario. | source code
eliminar_suelo(self) Elimina el suelo del escenario. | source code
eliminar_techo(self) Elimina el techo del escenario. | source code
eliminar_paredes(self) Elimina las dos paredes del escenario. | source code
eliminar_figura(self, figura) Elimina una figura del escenario. | source code
obtener_distancia_al_suelo(self, x, y, dy) Obtiene la distancia hacia abajo desde el punto (x,y). | source code
obtener_cuerpos_en(self, x, y) Retorna una lista de cuerpos que se encuentran en la posicion (x, y) o retorna una lista vacia []. | source code
definir_gravedad(self, x, y) Define la gravedad del motor de física. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, area, gravedad) (Constructor) | source code
Inicializa el motor de física. :param area: El area del escenario, en forma de tupla. :param gravedad: La aceleración del escenario. Overrides: object.__init__

### capturar_figura_con_el_mouse(self, figura) | source code
Comienza a capturar una figura con el mouse. :param figura: La figura a controlar con el mouse.

### cuando_mueve_el_mouse(self, x, y) | source code
Gestiona el evento de movimiento del mouse. :param x: Coordenada horizontal del mouse. :param y: Coordenada vertical del mouse.

### dibujar_figuras_sobre_lienzo(self, motor, lienzo, grosor=1) | source code
Dibuja todas las figuras en una pizarra. Indicado para depuracion. :param motor: Referencia al motor de pilas. :param lienzo: Un actor lienzo sobre el que se dibujará. :param grosor: El grosor de la linea medida en pixels.

### crear_cuerpo(self, definicion_de_cuerpo) | source code
Genera un Body de box2d. :param definicion_de_cuerpo: Los parámetros de configuración de un cuerpo para Box2d.

### crear_suelo(self, (ancho, alto), restitucion=0) | source code
Genera un suelo sólido para el escenario. :param ancho: El ancho del suelo. :param alto: Alto del suelo. :param restitucion: El grado de conservación de energía ante una colisión.

### crear_techo(self, (ancho, alto), restitucion=0) | source code
Genera un techo sólido para el escenario. :param ancho: El ancho del techo. :param alto: Alto del techo. :param restitucion: El grado de conservación de energía ante una colisión.

### crear_paredes(self, (ancho, alto), restitucion=0) | source code
Genera dos paredes para el escenario. :param ancho: El ancho de las paredes. :param alto: El alto de las paredes. :param restitucion: El grado de conservación de energía ante una colisión.

### eliminar_figura(self, figura) | source code
Elimina una figura del escenario. :param figura: Figura a eliminar.

### obtener_distancia_al_suelo(self, x, y, dy) | source code
Obtiene la distancia hacia abajo desde el punto (x,y). El valor de 'dy' tiene que ser positivo. Si la funcion no encuentra obstaculos retornara dy, pero en paso contrario retornara un valor menor a dy. :param x: posición horizontal del punto a analizar. :param y: posición vertical del punto a analizar.

### obtener_cuerpos_en(self, x, y) | source code
Retorna una lista de cuerpos que se encuentran en la posicion (x, y) o retorna una lista vacia []. :param x: posición horizontal del punto a analizar. :param y: posición vertical del punto a analizar.

### definir_gravedad(self, x, y) | source code
Define la gravedad del motor de física. :param x: Aceleración horizontal. :param y: Aceleración vertical.